Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MarshalJSON ¶
func UnmarshalDateTime ¶
func UnmarshalJSON ¶
Types ¶
type Decimal ¶
func (Decimal) MarshalGQL ¶
MarshalGQL implements the graphql.Marshaler interface found in gqlgen, allowing the type to be marshaled by gqlgen and sent over the wire. This will convert the Decimal to a JSON number as a string.
func (*Decimal) UnmarshalGQL ¶
UnmarshalGQL implements the graphql.Unmarshaler interface found in gqlgen, allowing the type to be received by a graphql client and unmarshaled.
Click to show internal directories.
Click to hide internal directories.